From 195d30e2e01fe2f91ed3bdaeec3982aa66b309dd Mon Sep 17 00:00:00 2001
From: Marc Kleine-Budde <mkl@pengutronix.de>
Date: Tue, 1 Dec 2009 20:57:45 +0100
Subject: [PATCH 5/5] Makefile.in: replace IROOT by DESTDIR

This patch replaces IROOT by DESTDIR, which is the autotools standard
variable. For backwards compatibilty IROOT overwrites the DESTDIR.

Signed-off-by: Marc Kleine-Budde <mkl@pengutronix.de>
---
 Makefile.in |   64 +++++++++++++++++++++++++++++++-----------------------------
 1 file changed, 34 insertions(+), 30 deletions(-)

Index: at-3.1.12/Makefile.in
===================================================================
--- at-3.1.12.orig/Makefile.in
+++ at-3.1.12/Makefile.in
@@ -16,6 +16,10 @@ docdir		= $(prefix)/doc
 atdocdir	= $(docdir)/at
 etcdir		= @ETCDIR@
 
+ifdef IROOT
+DESTDIR		= $(IROOT)
+endif
+
 DAEMON_USERNAME	= @DAEMON_USERNAME@
 DAEMON_GROUPNAME= @DAEMON_GROUPNAME@
 LOADAVG_MX	= @LOADAVG_MX@
@@ -86,38 +90,38 @@ atrun: atrun.in
 	$(CC) -c $(CFLAGS) $(DEFS) $*.c
 
 install: all
-	$(INSTALL) -g root -o root -m 755 -d $(IROOT)$(etcdir)
-	$(INSTALL) -g root -o root -m 755 -d $(IROOT)$(bindir)
-	$(INSTALL) -g root -o root -m 755 -d $(IROOT)$(sbindir)
-	$(INSTALL) -g root -o root -m 755 -d $(IROOT)$(docdir)
-	$(INSTALL) -g root -o root -m 755 -d $(IROOT)$(atdocdir)
-	$(INSTALL) -g $(DAEMON_GROUPNAME) -o $(DAEMON_USERNAME) -m 755 -d $(IROOT)$(ATSPOOL_DIR) $(IROOT)$(ATJOB_DIR)
-	chmod 1770 $(IROOT)$(ATSPOOL_DIR) $(IROOT)$(ATJOB_DIR)
-	touch $(IROOT)$(LFILE)
-	chmod 600 $(IROOT)$(LFILE)
-	chown $(DAEMON_USERNAME):$(DAEMON_GROUPNAME) $(IROOT)$(LFILE)
-	test -f $(IROOT)$(etcdir)/at.allow || test -f $(IROOT)$(etcdir)/at.deny || $(INSTALL) -o root -g $(DAEMON_GROUPNAME) -m 640 at.deny $(IROOT)$(etcdir)/
-	$(INSTALL) -g $(DAEMON_GROUPNAME) -o $(DAEMON_USERNAME) -m 6755 -s at $(IROOT)$(bindir)
-	$(LN_S) -f at $(IROOT)$(bindir)/atq
-	$(LN_S) -f at $(IROOT)$(bindir)/atrm
-	$(INSTALL) -g root -o root -m 755 batch $(IROOT)$(bindir)
-	$(INSTALL) -d -o root -g root -m 755 $(IROOT)$(man1dir)
-	$(INSTALL) -d -o root -g root -m 755 $(IROOT)$(man5dir)
-	$(INSTALL) -d -o root -g root -m 755 $(IROOT)$(man8dir)
-	$(INSTALL) -g root -o root -m 755 -s atd $(IROOT)$(sbindir)
-	$(INSTALL) -g root -o root -m 755 atrun $(IROOT)$(sbindir)
-	$(INSTALL) -g root -o root -m 644 at.1 $(IROOT)$(man1dir)/
-	cd $(IROOT)$(man1dir) && $(LN_S) -f at.1 atq.1 && $(LN_S) -f at.1 batch.1 && $(LN_S) -f at.1 atrm.1
-	$(INSTALL) -g root -o root -m 644 atd.8 $(IROOT)$(man8dir)/
+	$(INSTALL) -g root -o root -m 755 -d $(DESTDIR)$(etcdir)
+	$(INSTALL) -g root -o root -m 755 -d $(DESTDIR)$(bindir)
+	$(INSTALL) -g root -o root -m 755 -d $(DESTDIR)$(sbindir)
+	$(INSTALL) -g root -o root -m 755 -d $(DESTDIR)$(docdir)
+	$(INSTALL) -g root -o root -m 755 -d $(DESTDIR)$(atdocdir)
+	$(INSTALL) -g $(DAEMON_GROUPNAME) -o $(DAEMON_USERNAME) -m 755 -d $(DESTDIR)$(ATSPOOL_DIR) $(DESTDIR)$(ATJOB_DIR)
+	chmod 1770 $(DESTDIR)$(ATSPOOL_DIR) $(DESTDIR)$(ATJOB_DIR)
+	touch $(DESTDIR)$(LFILE)
+	chmod 600 $(DESTDIR)$(LFILE)
+	chown $(DAEMON_USERNAME):$(DAEMON_GROUPNAME) $(DESTDIR)$(LFILE)
+	test -f $(DESTDIR)$(etcdir)/at.allow || test -f $(DESTDIR)$(etcdir)/at.deny || $(INSTALL) -o root -g $(DAEMON_GROUPNAME) -m 640 at.deny $(DESTDIR)$(etcdir)/
+	$(INSTALL) -g $(DAEMON_GROUPNAME) -o $(DAEMON_USERNAME) -m 6755 -s at $(DESTDIR)$(bindir)
+	$(LN_S) -f at $(DESTDIR)$(bindir)/atq
+	$(LN_S) -f at $(DESTDIR)$(bindir)/atrm
+	$(INSTALL) -g root -o root -m 755 batch $(DESTDIR)$(bindir)
+	$(INSTALL) -d -o root -g root -m 755 $(DESTDIR)$(man1dir)
+	$(INSTALL) -d -o root -g root -m 755 $(DESTDIR)$(man5dir)
+	$(INSTALL) -d -o root -g root -m 755 $(DESTDIR)$(man8dir)
+	$(INSTALL) -g root -o root -m 755 -s atd $(DESTDIR)$(sbindir)
+	$(INSTALL) -g root -o root -m 755 atrun $(DESTDIR)$(sbindir)
+	$(INSTALL) -g root -o root -m 644 at.1 $(DESTDIR)$(man1dir)/
+	cd $(DESTDIR)$(man1dir) && $(LN_S) -f at.1 atq.1 && $(LN_S) -f at.1 batch.1 && $(LN_S) -f at.1 atrm.1
+	$(INSTALL) -g root -o root -m 644 atd.8 $(DESTDIR)$(man8dir)/
 	sed "s,\$${exec_prefix},$(exec_prefix),g" <atrun.8>tmpman
-	$(INSTALL) -g root -o root -m 644 tmpman $(IROOT)$(man8dir)/atrun.8
+	$(INSTALL) -g root -o root -m 644 tmpman $(DESTDIR)$(man8dir)/atrun.8
 	rm -f tmpman
-	$(INSTALL) -g root -o root -m 644 at_allow.5 $(IROOT)$(man5dir)/
-	cd $(IROOT)$(man5dir) && $(LN_S) -f at_allow.5 at_deny.5 
-	$(INSTALL) -g root -o root -m 644 $(DOCS) $(IROOT)$(atdocdir)
-	rm -f $(IROOT)$(mandir)/cat1/at.1* $(IROOT)$(mandir)/cat1/batch.1* \
-		$(IROOT)$(mandir)/cat1/atq.1*
-	rm -f $(IROOT)$(mandir)/cat1/atd.8*
+	$(INSTALL) -g root -o root -m 644 at_allow.5 $(DESTDIR)$(man5dir)/
+	cd $(DESTDIR)$(man5dir) && $(LN_S) -f at_allow.5 at_deny.5 
+	$(INSTALL) -g root -o root -m 644 $(DOCS) $(DESTDIR)$(atdocdir)
+	rm -f $(DESTDIR)$(mandir)/cat1/at.1* $(DESTDIR)$(mandir)/cat1/batch.1* \
+		$(DESTDIR)$(mandir)/cat1/atq.1*
+	rm -f $(DESTDIR)$(mandir)/cat1/atd.8*
 
 dist: checkin $(DIST) $(LIST) Filelist.asc
 	(cd ..; tar cf - `for a in $(DIST) $(LIST); do echo at-$(VERSION)/$$a; done` |\
